import {
  Column,
  Entity,
  JoinTable,
  ManyToMany,
  ManyToOne,
  OneToMany,
} from 'typeorm';
import { Base } from './bases/base';
import { Book } from './book';
import { CopyType } from './copyType';
import { Language } from './language';
import { Source } from './source';
import { Translator } from './translator';

@Entity()
export class Copy extends Base {
  @ManyToOne(() => Book, book => book.copies, {
    nullable: false,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  public original: Promise<Book>;

  @Column({ nullable: false, default: false })
  public favorites: boolean;

  @OneToMany(() => CopyType, copyType => copyType.copy)
  public types: Promise<CopyType[]>;

  @Column({ nullable: true })
  public isDigital: boolean;

  @ManyToMany(() => Source, {
    nullable: false,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  @JoinTable()
  public sources: Promise<Source[]>;

  @ManyToMany(() => Language, {
    nullable: true,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  @JoinTable()
  public languages: Promise<Language[]>;

  @ManyToMany(() => Translator, {
    nullable: true,
    onDelete: 'CASCADE',
    onUpdate: 'CASCADE',
  })
  @JoinTable()
  public translators: Promise<Translator[]>;
}
